@@ -11,8 +11,9 @@ mistnet_default <- function() {
 #' Initialize the 'MistNet' system if enabled.
 #' @param version version of 'MistNet' library
 #' @param reload if 'MistNet' library should be reloaded or not, default FALSE.
+#' @param verbose Logical, when `TRUE` prints text to console.
 #' @keywords internal
-mistnet_start <- function(version = mistnet_default(), reload = FALSE) {
+mistnet_start <- function(version = mistnet_default(), reload = FALSE, verbose = TRUE) {
   if (!mistnet_exists()) {
     stop("'MistNet' is disabled.")
   }
@@ -23,13 +24,13 @@ mistnet_start <- function(version = mistnet_default(), reload = FALSE) {
 
   # Path where the DLL should be
   dll_path <- file.path(install_path(), "lib")
-  message("Attempting to load MistNet from:", dll_path, "\n")
+  if(verbose) message("Attempting to load MistNet from:", dll_path, "\n")
 
   # Try-catch block to capture any errors during initialization
   tryCatch({
     cpp_mistnet_init(dll_path)
     .globals$mistnet_started <- TRUE
-      message("MistNet successfully initialized.\n")
+      if(verbose) message("MistNet successfully initialized.\n")
   }, error = function(e) {
       stop("Error during MistNet initialization: ", e$message, "\n")
   }, warning = function(w) {
